@@ -30,7 +30,7 @@ def validated_code(v: str) -> str:
         raise ValueError("Invalid Grid code: must be str")
     if not CODE_PATTERN.fullmatch(v):
         raise ValueError(
-            f"Invalid Grid code: {v}" f" does not match the regex {CODE_REGEX}"
+            f"Invalid Grid code: {v} does not match the regex {CODE_REGEX}"
         )
     return v
 
