@@ -18,15 +18,33 @@ if TYPE_CHECKING:
 # Import after above class definition
 from pystac.validation.stac_validator import JsonSchemaSTACValidator, STACValidator
 
+__all__ = [
+    "GetSchemaError",
+    "JsonSchemaSTACValidator",
+    "RegisteredValidator",
+    "validate",
+    "validate_all",
+    "validate_dict",
+    "validate_all_dict",
+    "set_validator",
+]
 
-def validate(stac_object: STACObject) -> list[Any]:
+
+def validate(
+    stac_object: STACObject,
+    validator: STACValidator | None = None,
+) -> list[Any]:
     """Validates a :class:`~pystac.STACObject`.
 
     Args:
         stac_object : The stac object to validate.
+        validator : A custom validator to use for validation of the STAC object.
+            If omitted, the default validator from
+            :class:`~pystac.validation.RegisteredValidator`
+            will be used instead.
 
     Returns:
-        List[Object]: List of return values from the validation calls for the
+        List[Any]: List of return values from the validation calls for the
            core object and any extensions. Element type is specific to the
            STACValidator implementation.
 
@@ -39,6 +57,7 @@ def validate(stac_object: STACObject) -> list[Any]:
         stac_version=pystac.get_stac_version(),
         extensions=stac_object.stac_extensions,
         href=stac_object.get_self_href(),
+        validator=validator,
     )
 
 
@@ -48,12 +67,14 @@ def validate_dict(
     stac_version: str | None = None,
     extensions: list[str] | None = None,
     href: str | None = None,
+    validator: STACValidator | None = None,
 ) -> list[Any]:
     """Validate a stac object serialized as JSON into a dict.
 
     This method delegates to the call to
-    :meth:`pystac.validation.STACValidator.validate` for the STACValidator registered
-    via :meth:`~pystac.validation.set_validator` or
+    :meth:`~pystac.validation.stac_validator.STACValidator.validate` for the
+    :class:`~pystac.validation.stac_validator.STACValidator` registered
+    via :func:`~pystac.validation.set_validator` or
     :class:`~pystac.validation.JsonSchemaSTACValidator` by default.
 
     Args:
@@ -67,9 +88,13 @@ def validate_dict(
         extensions : Extension IDs for this stac object. If not supplied,
             PySTAC's identification logic to identify the extensions.
         href : Optional HREF of the STAC object being validated.
+        validator : A custom validator to use for validation of the STAC dictionary.
+            If omitted, the default validator from
+            :class:`~pystac.validation.RegisteredValidator`
+            will be used instead.
 
     Returns:
-        List[Object]: List of return values from the validation calls for the
+        List[Any]: List of return values from the validation calls for the
            core object and any extensions. Element type is specific to the
            STACValidator implementation.
 
@@ -104,7 +129,8 @@ def validate_dict(
 
         extensions = [uri for uri in map(_get_uri, extensions) if uri is not None]
 
-    return RegisteredValidator.get_validator().validate(
+    validator = validator or RegisteredValidator.get_validator()
+    return validator.validate(
         stac_dict, stac_object_type, stac_version, extensions, href
     )
 
@@ -128,10 +154,11 @@ def validate_all(
             the StacIO.default() instance is used.
 
     Raises:
-        STACValidationError: if the STAC object or any contained catalog, collection,
-            or item has a validation error
-        ValueError: if stac_object is a STACObject and href is not None, or if
-            stacl_object is a dict and href is None
+        STACValidationError or ValueError: STACValidationError is raised
+            if the STAC object or any contained catalog, collection,
+            or item has a validation error. ValueError is raised
+            if stac_object is a STACObject and href is not None, or if
+            stac_object is a dict and href is None.
     """
     if stac_io is None:
         stac_io = pystac.StacIO.default()
@@ -180,7 +207,7 @@ def validate_all_dict(
 
     Raises:
         STACValidationError: if the STAC object or any contained catalog, collection,
-        or item has a validation error
+            or item has a validation error
     """
     if stac_io is None:
         stac_io = pystac.StacIO.default()
@@ -246,6 +273,3 @@ def set_validator(validator: STACValidator) -> None:
             validation.
     """
     RegisteredValidator.set_validator(validator)
-
-
-__all__ = ["GetSchemaError"]
