@@ -4,7 +4,6 @@ import json
 import os
 import posixpath
 import tempfile
-import unittest
 from collections import defaultdict
 from collections.abc import Iterator
 from copy import deepcopy
@@ -46,7 +45,7 @@ from tests.utils import (
 )
 
 
-class CatalogTypeTest(unittest.TestCase):
+class TestCatalogType:
     def test_determine_type_for_absolute_published(self) -> None:
         cat = TestCases.case_1()
         with tempfile.TemporaryDirectory() as tmp_dir:
@@ -56,7 +55,7 @@ class CatalogTypeTest(unittest.TestCase):
             )
 
         catalog_type = CatalogType.determine_type(cat_json)
-        self.assertEqual(catalog_type, CatalogType.ABSOLUTE_PUBLISHED)
+        assert catalog_type == CatalogType.ABSOLUTE_PUBLISHED
 
     def test_determine_type_for_relative_published(self) -> None:
         cat = TestCases.case_2()
@@ -67,14 +66,14 @@ class CatalogTypeTest(unittest.TestCase):
             )
 
         catalog_type = CatalogType.determine_type(cat_json)
-        self.assertEqual(catalog_type, CatalogType.RELATIVE_PUBLISHED)
+        assert catalog_type == CatalogType.RELATIVE_PUBLISHED
 
     def test_determine_type_for_self_contained(self) -> None:
         cat_json = pystac.StacIO.default().read_json(
             TestCases.get_path("data-files/catalogs/test-case-1/catalog.json")
         )
         catalog_type = CatalogType.determine_type(cat_json)
-        self.assertEqual(catalog_type, CatalogType.SELF_CONTAINED)
+        assert catalog_type == CatalogType.SELF_CONTAINED
 
     def test_determine_type_for_unknown(self) -> None:
         catalog = Catalog(id="test", description="test desc")
@@ -83,7 +82,7 @@ class CatalogTypeTest(unittest.TestCase):
         catalog.normalize_hrefs("http://example.com")
         d = catalog.to_dict(include_self_link=False)
 
-        self.assertIsNone(CatalogType.determine_type(d))
+        assert CatalogType.determine_type(d) is None
 
 
 class TestCatalog:
@@ -421,9 +420,9 @@ class TestCatalog:
                     c.id for c in children
                 }, "Children unequal"
 
-                assert {c.id for c in root.get_items()} == {
-                    c.id for c in items
-                }, "Items unequal"
+                assert {c.id for c in root.get_items()} == {c.id for c in items}, (
+                    "Items unequal"
+                )
 
             assert actual_catalog_iterations == expected_catalog_iterations
 
@@ -461,10 +460,10 @@ class TestCatalog:
             actual_counts = actual_link_types_to_counts[obj_id]
             assert set(expected_counts.keys()) == set(actual_counts.keys())
             for rel in expected_counts:
-                assert (
-                    actual_counts[rel] == expected_counts[rel]
-                ), "Clone of {} has {} {} links, original has {}".format(
-                    obj_id, actual_counts[rel], rel, expected_counts[rel]
+                assert actual_counts[rel] == expected_counts[rel], (
+                    "Clone of {} has {} {} links, original has {}".format(
+                        obj_id, actual_counts[rel], rel, expected_counts[rel]
+                    )
                 )
 
     def test_save_uses_previous_catalog_type(self) -> None:
@@ -555,12 +554,12 @@ class TestCatalog:
 
             # Check the root catalog path
             expected_root_catalog_path = os.path.join(tmp_dir, "catalog.json")
-            assert os.path.exists(
-                expected_root_catalog_path
-            ), f"{expected_root_catalog_path} does not exist."
-            assert os.path.isfile(
-                expected_root_catalog_path
-            ), f"{expected_root_catalog_path} is not a file."
+            assert os.path.exists(expected_root_catalog_path), (
+                f"{expected_root_catalog_path} does not exist."
+            )
+            assert os.path.isfile(expected_root_catalog_path), (
+                f"{expected_root_catalog_path} is not a file."
+            )
 
             # Check each child catalog
             for child_catalog in catalog.get_children():
@@ -572,12 +571,12 @@ class TestCatalog:
                     expected_root_catalog_path,
                     start_is_dir=False,
                 )
-                assert os.path.exists(
-                    expected_child_path
-                ), f"{expected_child_path} does not exist."
-                assert os.path.isfile(
-                    expected_child_path
-                ), f"{expected_child_path} is not a file."
+                assert os.path.exists(expected_child_path), (
+                    f"{expected_child_path} does not exist."
+                )
+                assert os.path.isfile(expected_child_path), (
+                    f"{expected_child_path} is not a file."
+                )
 
             # Check each item
             for item in catalog.get_items(recursive=True):
@@ -589,12 +588,12 @@ class TestCatalog:
                     expected_root_catalog_path,
                     start_is_dir=False,
                 )
-                assert os.path.exists(
-                    expected_item_path
-                ), f"{expected_item_path} does not exist."
-                assert os.path.isfile(
-                    expected_item_path
-                ), f"{expected_item_path} is not a file."
+                assert os.path.exists(expected_item_path), (
+                    f"{expected_item_path} does not exist."
+                )
+                assert os.path.isfile(expected_item_path), (
+                    f"{expected_item_path} is not a file."
+                )
 
     def test_clone_uses_previous_catalog_type(self) -> None:
         catalog = TestCases.case_1()
@@ -614,10 +613,10 @@ class TestCatalog:
                     target_href = cast(pystac.STACObject, link.target).self_href
                 else:
                     target_href = link.absolute_href
-                assert (
-                    "http://example.com" in target_href
-                ), '[{}] {} does not contain "{}"'.format(
-                    link.rel, target_href, "http://example.com"
+                assert "http://example.com" in target_href, (
+                    '[{}] {} does not contain "{}"'.format(
+                        link.rel, target_href, "http://example.com"
+                    )
                 )
             for item in items:
                 assert "http://example.com" in item.self_href
@@ -749,9 +748,9 @@ class TestCatalog:
         assert len(result) == 0
         catalog.normalize_hrefs("/tmp")
         for item in catalog.get_items(recursive=True):
-            assert (
-                item.get_self_href() == expected_hrefs[item.id]
-            ), f" for item '{item.id}'"
+            assert item.get_self_href() == expected_hrefs[item.id], (
+                f" for item '{item.id}'"
+            )
 
     def test_generate_subcatalogs_works_after_adding_more_items(self) -> None:
         catalog = Catalog(id="test", description="Test")
@@ -1152,9 +1151,9 @@ class TestCatalog:
                     continue
 
                 href = link["href"]
-                assert not is_absolute_href(
-                    href
-                ), f"Link with rel={link['rel']} is absolute!"
+                assert not is_absolute_href(href), (
+                    f"Link with rel={link['rel']} is absolute!"
+                )
 
     def test_full_copy_and_normalize_works_with_created_stac(self) -> None:
         cat = TestCases.case_3()
@@ -1423,7 +1422,7 @@ class TestCatalog:
         Catalog.from_dict(d)
 
 
-class FullCopyTest(unittest.TestCase):
+class TestFullCopy:
     def check_link(self, link: pystac.Link, tag: str) -> None:
         if link.is_resolved():
             target_href: str = cast(pystac.STACObject, link.target).self_href
@@ -1438,7 +1437,7 @@ class FullCopyTest(unittest.TestCase):
             self.check_link(link, tag)
 
     def check_catalog(self, c: Catalog, tag: str) -> None:
-        self.assertEqual(len(c.get_links("root")), 1, msg=f"{c}")
+        assert len(c.get_links("root")) == 1, f"Failure for catalog: {c}"
 
         for link in c.links:
             self.check_link(link, tag)
@@ -1540,7 +1539,7 @@ class FullCopyTest(unittest.TestCase):
             assert os.path.exists(href)
 
 
-class CatalogSubClassTest(unittest.TestCase):
+class TestCatalogSubClass:
     """This tests cases related to creating classes inheriting from pystac.Catalog to
     ensure that inheritance, class methods, etc. function as expected."""
 
@@ -1553,25 +1552,20 @@ class CatalogSubClassTest(unittest.TestCase):
             # backwards compatibility of inherited classes
             return super().get_items()
 
-    def setUp(self) -> None:
-        self.stac_io = pystac.StacIO.default()
-
     def test_from_dict_returns_subclass(self) -> None:
+        self.stac_io = pystac.StacIO.default()
         catalog_dict = self.stac_io.read_json(self.case_1)
         custom_catalog = self.BasicCustomCatalog.from_dict(catalog_dict)
-
-        self.assertIsInstance(custom_catalog, self.BasicCustomCatalog)
+        assert isinstance(custom_catalog, self.BasicCustomCatalog)
 
     def test_from_file_returns_subclass(self) -> None:
         custom_catalog = self.BasicCustomCatalog.from_file(self.case_1)
-
-        self.assertIsInstance(custom_catalog, self.BasicCustomCatalog)
+        assert isinstance(custom_catalog, self.BasicCustomCatalog)
 
     def test_clone(self) -> None:
         custom_catalog = self.BasicCustomCatalog.from_file(self.case_1)
         cloned_catalog = custom_catalog.clone()
-
-        self.assertIsInstance(cloned_catalog, self.BasicCustomCatalog)
+        assert isinstance(cloned_catalog, self.BasicCustomCatalog)
 
     def test_get_all_items_works(self) -> None:
         custom_catalog = self.BasicCustomCatalog.from_file(self.case_1)
